import tensorflow as tf
from tensorflow import keras
import pandas as pd


def plot_history(history, contains, skip=0):
    df = pd.DataFrame(history.history)
    df[list(df.filter(regex=contains))].iloc[skip:].plot()


def categorical_fit_transform(df, cat_cols):
    df = df.copy()
    cat_features_map = {}
    df[cat_cols] = df[cat_cols].astype("category")
    for cat_col in cat_cols:
        cat_features_map[cat_col] = dict(enumerate(df[cat_col].cat.categories, start=1))
        df[cat_col] = df[cat_col].cat.codes + 1
    return df, cat_features_map


def categorical_transform(df, cat_features_map):
    df = df.copy()
    for cat_col in cat_features_map:
        df[cat_col] = df[cat_col].map(
            {value: key for key, value in cat_features_map[cat_col].items()}
        )
        df[cat_col].fillna(value=0, inplace=True)
        df[cat_col] = df[cat_col].astype(int)
    return df


def continuous_fit_transform(df, cont_cols):
    df = df.copy()
    cont_features_map = {}
    df[cont_cols] = df[cont_cols].astype(float)
    for cont_col in cont_cols:
        cont_features_map[cont_col] = {
            "mean": df[cont_col].mean(),
            "std": df[cont_col].std(),
        }
        df[cont_col] = (
                           df[cont_col] - cont_features_map[cont_col]["mean"]
                       ) / cont_features_map[cont_col]["std"]
    return df, cont_features_map


def continuous_transform(df, cont_features_map):
    df = df.copy()
    for cont_col in cont_features_map:
        df[cont_col] = (
            df[cont_col] - cont_features_map[cont_col]["mean"]
        ) / cont_features_map[cont_col]["std"]
    return df



import re
import os
import shutil
import doctest
from typing import Optional



def setup_kaggle() -> None:
    """
    Function is used to setup Kaggle environment for dataset or competition downloading.
    """
    x = [f for f in os.listdir(os.curdir) if re.search('kaggle.*\.json', f)]
    assert len(x) == 1, 'Too much kaggle.json files'
    assert re.match('kaggle.*\.json', x[0]), 'Upload kaggle.json file'
    if not os.path.exists('/root/.kaggle'):
        os.makedirs('/root/.kaggle')
    shutil.move(x[0], '/root/.kaggle/kaggle.json')
    os.chmod('/root/.kaggle/kaggle.json', 0o600)


def download_kaggle_data(COMPETITION: Optional[str]=None, DATA_DIR: Optional[str]=None) -> None:
    """
    Downloads datasets from Kaggle.
    :param COMPETITION: Kaggle command to download datasets.
    :param DATA_DIR: Directory where to save files. If not specified, files are saved in working directory.
    :return: Downloads files.
    """
    if COMPETITION:
        if not DATA_DIR:
            os.system(COMPETITION)
        else:
            os.system('{} --unzip -p {}'.format(COMPETITION, str(DATA_DIR)))


def unarchive_data(
        FILES_TO_UNZIP: Optional[list]=None,
        DATA_DIR: Optional[str]=None,
        USE_SUBFOLDERS: Optional[bool]=False,
    ) -> None:
    """
    Used to unarchive specified files.
    :param FILES_TO_UNZIP: list of files to unarchive.
    :param DATA_DIR: directory where to save unarcjived data.
    :param USE_SUBFOLDERS: If True creates subfolders for data item. Default: False.
    :return: None
    """
    for filename in FILES_TO_UNZIP:
        # TODO path or string and destination folder
        if USE_SUBFOLDERS:
            # TODO add tar and etc
            dir_name = filename.split('.')[0]
        else:
            dir_name = ''
        shutil.unpack_archive(str(DATA_DIR/filename), extract_dir=str(DATA_DIR/dir_name))



if __name__ == '__main__':
    download_kaggle_data()


import os
from pathlib import Path
import time
import json
import re
import pickle
import shutil
from functools import partial
import math

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns
from PIL import Image
from sklearn.base import BaseEstimator, TransformerMixin
from sklearn.compose import ColumnTransformer
from sklearn.decomposition import PCA, KernelPCA
from sklearn.ensemble import RandomForestClassifier, RandomForestRegressor
from sklearn.impute import MissingIndicator, SimpleImputer
from sklearn.metrics import (
    accuracy_score,
    classification_report,
    confusion_matrix,
    explained_variance_score,
    f1_score,
    log_loss,
    mean_absolute_error,
    mean_squared_error,
    mean_squared_log_error,
    precision_score,
    r2_score,
    recall_score,
)
from sklearn.model_selection import GridSearchCV, RandomizedSearchCV, train_test_split
from sklearn.pipeline import Pipeline
from sklearn.preprocessing import (
    Binarizer,
    LabelEncoder,
    MinMaxScaler,
    MultiLabelBinarizer,
    Normalizer,
    OneHotEncoder,
    OrdinalEncoder,
    PolynomialFeatures,
    RobustScaler,
    StandardScaler,
)

import tensorflow as tf
from tensorflow import keras

# My imports
from dlai.colab_utils import setup_kaggle
from dlai.colab_utils import download_kaggle_data
from dlai.colab_utils import unarchive_data


import setuptools

# read the contents of your README file
with open("README.md", "r") as f:
    long_description = f.read()

setuptools.setup(
    name="dlai",
    version="0.0.8",
    author="Laura Lu",
    author_email="new4spam@gmail.com",
    description="DL & ML helper library",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="",
    download_url="",
    packages=setuptools.find_packages(),
    install_requires=[
        "numpy",
        "Pillow",
        "matplotlib",
        "tensorflow-gpu==2.0.0-beta1",
        "seaborn"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
